DWImagePickerIOS class

An implementation of DWImagePickerPlatform that uses method channels.

Inheritance
  • Object
  • PlatformInterface
  • DWImagePickerIOS

Constructors

DWImagePickerIOS()

Properties

hashCode int
The hash code for this object.
no setterinherited
methodChannel MethodChannel
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openCamera({DWCameraOptions? cameraOptions, bool? cropping, DWCropOptions? cropOptions, LocalizedImageCropper? localized}) Future<DWPickerItem>
Take a photo or record a video
openCropper(String imagePath, {DWCropOptions? cropOptions, LocalizedImageCropper? localized}) Future<DWPickerItem>
Open image cropper
openPicker({List<String>? selectedIds, DWPickerOptions? pickerOptions, bool? cropping, DWCropOptions? cropOptions, LocalizedImagePicker? localized}) Future<List<DWPickerItem>>
Select images or videos from a library
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

registerWith() → void