minFileSizeErrorText property
The error message displayed when the selected file is below the minimum file size.
Default: 'The file size is too small'
Implementation
final String? minFileSizeErrorText;
The error message displayed when the selected file is below the minimum file size.
Default: 'The file size is too small'
final String? minFileSizeErrorText;